==> eclipse-wtp_3.4.2.orig.tar.xz: eclipse-wtp-3.4.2/org.eclipse.wst.jsdt.core/src/org/eclipse/wst/jsdt/internal/core/util/ReferenceInfoAdapter.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.wst.jsdt.internal.core.util;

/**
 * An adapter which implements the methods for handling
 * reference information from the parser.
 */
public abstract class ReferenceInfoAdapter {
/**
 * Does nothing.
 */
public void acceptConstructorReference(char[] typeName, int argCount, int sourcePosition) {
	// Does nothing
}
/**
 * Does nothing.
 */
public void acceptFieldReference(char[] fieldName, int sourcePosition) {
	// Does nothing
}
/**
 * Does nothing.
 */
public void acceptMethodReference(char[] methodName, int argCount, int sourcePosition) {
	// Does nothing
}
/**
 * Does nothing.
 */
public void acceptTypeReference(char[][] typeName, int sourceStart, int sourceEnd) {
	// Does nothing
}
/**
 * Does nothing.
 */
public void acceptTypeReference(char[] typeName, int sourcePosition) {
	// Does nothing
}
/**
 * Does nothing.
 */
public void acceptUnknownReference(char[][] name, int sourceStart, int sourceEnd) {
	// Does nothing
}
/**
 * Does nothing.
 */
public void acceptUnknownReference(char[] name, int sourcePosition) {
	// Does nothing
}
}

==> eclipse-wtp_3.5.2.orig.tar.xz: eclipse-wtp-3.5.2/org.eclipse.wst.jsdt.core/src/org/eclipse/wst/jsdt/internal/core/util/ReferenceInfoAdapter.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2011 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.wst.jsdt.internal.core.util;

/**
 * An adapter which implements the methods for handling
 * reference information from the parser.
 */
public abstract class ReferenceInfoAdapter {
/**
 * Does nothing.
 */
public void acceptConstructorReference(char[] typeName, int argCount, int sourcePosition) {
	// Does nothing
}
/**
 * Does nothing.
 */
public void acceptFieldReference(char[] fieldName, int sourcePosition) {
	// Does nothing
}
/**
 * Does nothing.
 */
public void acceptMethodReference(char[] methodName, int sourcePosition) {
	// Does nothing
}
/**
 * Does nothing.
 */
public void acceptTypeReference(char[][] typeName, int sourceStart, int sourceEnd) {
	// Does nothing
}
/**
 * Does nothing.
 */
public void acceptTypeReference(char[] typeName, int sourcePosition) {
	// Does nothing
}
/**
 * Does nothing.
 */
public void acceptUnknownReference(char[][] name, int sourceStart, int sourceEnd) {
	// Does nothing
}
/**
 * Does nothing.
 */
public void acceptUnknownReference(char[] name, int sourcePosition) {
	// Does nothing
}
}
